@@ -34,7 +34,7 @@ OF_ASSUME_NONNULL_BEGIN
 #ifdef __cplusplus
 extern "C" {
 #endif
-extern int _OFNumber_NSObject_reference;
+extern int _OFNumber_NSObject_reference OF_VISIBILITY_HIDDEN;
 #ifdef __cplusplus
 }
 #endif
